@@ -1,13 +1,14 @@
 package Test::App::GitGot::Repo::Git;
 use parent 'Test::App::GitGot::Repo';
 
-use strict;
+use 5.014;                      # strict, unicode_strings
 use warnings;
 
-use App::GitGot::Repo::Git;
 use Test::Exception;
 use Test::More;
 
+use App::GitGot::Repo::Git;
+
 sub fixtures :Test(startup) {
   my $test = shift;
 
@@ -20,16 +21,16 @@ sub test_current_branch :Tests(3) {
   my $test = shift;
 
   dies_ok { $test->{full}->current_branch } 'will die';
-  like( $@ , qr/Can't locate directory/ , 'expected error message' );
+  like( $@ , qr/(?:Can't locate|Failed to change) directory/ , 'expected error message' );
 
-  is( $test->{min}->current_branch , 'master' , 'expected answer' );
+  is( $test->{min}->current_branch , 'main' , 'expected answer' );
 }
 
 sub test_current_remote_branch :Tests(3) {
   my $test = shift;
 
   dies_ok { $test->{full}->current_branch } 'will die';
-  like( $@ , qr/Can't locate directory/ , 'expected error message' );
+  like( $@ , qr/(?:Can't locate|Failed to change) directory/ , 'expected error message' );
 
   is( $test->{min}->current_remote_branch , 0 , 'get 0 without real remote' );
 }
